.. _vallado:

Fundamentals of Astrodynamics and Applications, 4th Edition
===========================================================

.. image:: /images/vallado.jpg
   :align: center

|
| Author:  David A. Vallado
| ISBN-10: 1881883183
| ISBN-13: 978-1881883180
